@@ -1,4 +1,4 @@
-# $Id: crt.py 927 2014-06-05 16:14:50Z mwall $
+# $Id: crt.py 1029 2014-08-31 12:57:33Z mwall $
 # Copyright 2013 Matthew Wall
 
 # Emit loop data to file in Cumulus realtime format.
@@ -40,6 +40,8 @@ import weeutil.weeutil
 import weeutil.Sun
 from weewx.wxengine import StdService
 
+VERSION = 'X'
+
 COMPASS_POINTS = ['N','NNE','NE','ENE','E','ESE','SE','SSE',
                   'S','SSW','SW','WSW','W','WNW','NW','NNW','N']
 
@@ -149,7 +151,8 @@ def calcWindRun(archive, ts):
     for row in archive.genSql("SELECT `interval`,windSpeed FROM archive "
                               "WHERE dateTime>? AND dateTime<=?", 
                               (sod_ts, ts)):
-        run += row[1] * (row[0] / 60)
+        if row[1] is not None:
+            run += row[1] * (row[0] / 60)
     return run
 
 # calculate trend over past n hours, default to 3 hour window
